---
jupyter:
  kernelspec:
    display_name: Haskell
    language: haskell
    name: haskell
---

# Example Haskell Notebook


Define a function to add two numbers.

```{haskell}
f :: Num a => a -> a -> a
f x y = x + y
```

Try to use the function

```{haskell}
f 1 2 
```
